Changelog
=========

Version 1.0.2

  - fixed 'moke' script option parsing


Version 1.0.1
-------------

  - support for 'moke new'
  - added error when mokefile contains no functions
  

Version 1.0.0
-------------

  - Initial commit
